==> hs-vault-0.2.0.0_1.tbz: lib/ghc-7.4.1/cabal/vault-0.2.0.0/register.sh <==
#!/bin/sh
echo 'name: vault
version: 0.2.0.0
id: vault-0.2.0.0-9b371660370106e6adf0ae39cb1d3f68

license: BSD3
copyright: (c) Heinrich Apfelmus 2011
maintainer: Heinrich Apfelmus <apfelmus at quantentunnel de>
stability:
homepage: https://github.com/HeinrichApfelmus/vault
package-url:
synopsis: a persistent store for values of arbitrary types
description: A /vault/ is a persistent store for values of arbitrary types.
             It'\''s like having first-class access to the storage space behind IORefs.
             .
             The data structure is analogous to a bank vault,
             where you can access different bank boxes with different keys;
             hence the name.
             .
             Also provided is a /locker/ type, representing a store for a single element.
category: Data
author: Heinrich Apfelmus, Elliott Hird
exposed: True
exposed-modules: Data.Vault Data.Vault.ST Data.Unique.Really
hidden-modules: Data.Vault.ST_GHC Data.Vault.ST_Pure
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/vault-0.2.0.0
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/vault-0.2.0.0
              /usr/local/lib
hs-libraries: HSvault-0.2.0.0
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.5.0.0-1a022b3476300ed3e5bfdd46dd7221d0
         containers-0.4.2.1-7c54595400348f577b3b4a45691c5afd
         hashable-1.1.2.3-27291b4496c1ca7fa20544b20e210675
         unordered-containers-0.2.1.0-0c2c5493b800a003d2156e3491c7d967
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/vault-0.2.0.0/html/vault.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/vault-0.2.0.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-vault-0.2.0.4.tbz: lib/ghc-7.4.2/cabal/vault-0.2.0.4/register.sh <==
#!/bin/sh
echo 'name: vault
version: 0.2.0.4
id: vault-0.2.0.4-20d510d61304552bc0090463b5af1d1d

license: BSD3
copyright: (c) Heinrich Apfelmus 2011
maintainer: Heinrich Apfelmus <apfelmus at quantentunnel de>
stability:
homepage: https://github.com/HeinrichApfelmus/vault
package-url:
synopsis: a persistent store for values of arbitrary types
description: A /vault/ is a persistent store for values of arbitrary types.
             It'\''s like having first-class access to the storage space behind IORefs.
             .
             The data structure is analogous to a bank vault,
             where you can access different bank boxes with different keys;
             hence the name.
             .
             Also provided is a /locker/ type, representing a store for a single element.
category: Data
author: Heinrich Apfelmus, Elliott Hird
exposed: True
exposed-modules: Data.Vault Data.Vault.ST Data.Unique.Really
hidden-modules: Data.Vault.ST_GHC
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/vault-0.2.0.4
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/vault-0.2.0.4
              /usr/local/lib
hs-libraries: HSvault-0.2.0.4
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
         hashable-1.2.0.5-1049ae1ef267f5e5664cf9f54e9a7458
         unordered-containers-0.2.3.0-eea23be98f84f4fcc4f43b6a5a4ec815
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/vault-0.2.0.4/html/vault.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/vault-0.2.0.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
